pytilities.aop.aopmeta — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »

# pytilities.aop.aopmeta

class `pytilities.aop.aopmeta.` `AOPMeta`(name, bases, dictionary)

  Follows advice rules as described by Advisor

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.aop »